---
name: 2. PaddleX API使用问题
about: 使用PaddleX API所遇到的问题
title: ''
labels: ''
assignees: ''

---

## Checklist:

- [ ] 查找[历史相关issue](https://github.com/PaddlePaddle/PaddleX/issues)寻求解答
- [ ] 翻阅[FAQ](https://paddlepaddle.github.io/PaddleX/main/FAQ.html)
- [ ] 翻阅[PaddleX 文档](https://paddlepaddle.github.io/PaddleX/main/index.html)
- [ ] 确认bug是否在新版本里还未修复

## 描述问题

## 复现

1. 您是否已经正常运行我们提供的[教程](https://paddlepaddle.github.io/PaddleX/main/index.html)？

2. 您是否在教程的基础上修改代码内容？还请您提供运行的代码

3. 您使用的数据集是？

4. 请提供您出现的报错信息及相关log

## 环境

1. 请提供您使用的PaddlePaddle和PaddleX的版本号

2. 请提供您使用的操作系统信息，如Linux/Windows/MacOS

3. 请问您使用的Python版本是？

5. 请问您使用的CUDA/cuDNN的版本号是？
